==> eda4nlp-0.3.tar.gz: eda4nlp-0.3/setup.py <==
from distutils.core import setup
setup(
  name = 'eda4nlp',         # How you named your package folder (MyLib)
  packages = ['eda4nlp'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'TYPE YOUR DESCRIPTION HERE',   # Give a short description about your library
  author = 'Abishek Kamalanathan',                   # Type in your name
  author_email = 'neyveliabi@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/abishek21',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/abishek21/eda4nlp/archive/0.3.tar.gz',    # I explain this later on
  keywords = ['nlp', 'ngrams', 'eda'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'sklearn',
          'matplotlib',
          'numpy',
          'os'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> eda4nlp-1.2.tar.gz: eda4nlp-1.2/setup.py <==
from distutils.core import setup
setup(
  name = 'eda4nlp',         # How you named your package folder (MyLib)
  packages = ['eda4nlp'],   # Chose the same as "name"
  version = '1.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'TYPE YOUR DESCRIPTION HERE',   # Give a short description about your library
  author = 'Abishek Kamalanathan',                   # Type in your name
  author_email = 'neyveliabi@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/abishek21',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/abishek21/eda4nlp/archive/1.2.tar.gz',    # I explain this later on
  keywords = ['nlp', 'ngrams', 'eda','embeddings'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'sklearn',
          'matplotlib',
          'numpy'
          ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
